==> fightorflight-fabric-0.9.0-sources.jar: me/rufia/fightorflight/PokemonInterface.java <==
package me.rufia.fightorflight;

import com.cobblemon.mod.common.api.moves.Move;
import net.minecraft.class_2338;


public interface PokemonInterface {
    default int getAttackTime() {
        return 0;
    }


    default void setAttackTime(int val) {
    }

    default int getMaxAttackTime() {
        return 0;
    }


    default void setMaxAttackTime(int val) {
    }

    default boolean usingBeam() {
        return false;
    }


    default boolean usingSound() {
        return false;
    }

    default boolean usingMagic() {
        return false;
    }

    default void setCurrentMove(Move move) {
    }


    default String getCurrentMove() {
        return null;
    }


    default int getNextCryTime() {
        return 0;
    }

    default void setNextCryTime(int time) {
    }

    default String getCommand() {
        return "";
    }

    default void setCommand(String cmd) {
    }

    default String getCommandData() {
        return "";
    }

    default void setCommandData(String cmdData) {
    }

    default class_2338 getTargetBlockPos() {
        return null;
    }

    default void setTargetBlockPos(class_2338 blockPos) {
    }

    default int getCapturedBy() {
        return 0;
    }

    default void setCapturedBy(int id) {

    }

    default void refreshMovesList() {
    }

    default void switchMove(Move move) {
    }

    default void tryUsingStatusMoves() {
    }

    default int getAttackMode() {
        return 0;
    }

    default void setAttackMode(int attackMode) {
    }

    default int getMoveDuration() {
        return -1;
    }

    default void setMoveDuration(int duration) {
    }
}

==> fightorflight-fabric-0.10.0-sources.jar: me/rufia/fightorflight/PokemonInterface.java <==
package me.rufia.fightorflight;

import com.cobblemon.mod.common.api.moves.Move;
import net.minecraft.class_1309;
import net.minecraft.class_2338;
import org.jetbrains.annotations.Nullable;


public interface PokemonInterface {
    default int getAttackTime() {
        return 0;
    }


    default void setAttackTime(int val) {
    }

    default int getMaxAttackTime() {
        return 0;
    }


    default void setMaxAttackTime(int val) {
    }

    default boolean usingBeam() {
        return false;
    }


    default boolean usingSound() {
        return false;
    }

    default boolean usingMagic() {
        return false;
    }

    default void setCurrentMove(Move move) {
    }


    default String getCurrentMove() {
        return null;
    }


    default int getNextCryTime() {
        return 0;
    }

    default void setNextCryTime(int time) {
    }

    default String getCommand() {
        return "";
    }

    default void setCommand(String cmd) {
    }

    default String getCommandData() {
        return "";
    }

    default void setCommandData(String cmdData) {
    }

    default class_2338 getTargetBlockPos() {
        return null;
    }

    default void setTargetBlockPos(class_2338 blockPos) {
    }

    default int getCapturedBy() {
        return 0;
    }

    default void setCapturedBy(int id) {

    }

    default void refreshMovesList() {
    }

    default void switchMove(Move move) {
    }

    default void tryUsingStatusMoves() {
    }

    default int getAttackMode() {
        return 0;
    }

    default void setAttackMode(int attackMode) {
    }

    default int getMoveDuration() {
        return -1;
    }

    default void setMoveDuration(int duration) {
    }

    default class_1309 getOwnerLastHurt() {
        return null;
    }

    default void setOwnerLastHurt(@Nullable class_1309 livingEntity) {
    }

    default int getOwnerLastHurtTick() {
        return -1;
    }
}
